==> nmds.1.2.tgz: MDS_final/prep.f <==
      subroutine prep(dist,rbdwk,nbdwk,nbdsrt,nbdrnk,iperm,rval,
     &  notus1,ntbnd,nd1)
c
      implicit none
c
      integer notus1,ntbnd,nd1
c      
      real dist(0:notus1,0:notus1)
      real rbdwk(ntbnd),rval(0:nd1,0:notus1)
c      
      integer nbdsrt(0:1,ntbnd),nbdwk(0:1,ntbnd)
      integer nbdrnk(0:1,0:notus1,0:notus1)
      integer iperm(ntbnd)
c
      integer ibnd,iotus0,iotus1,kflag,ier,ntie,id,ibndp
c
      call distcal1(notus1,dist)
c
      ibnd=1
      do 100 iotus0=0,notus1
        do 100 iotus1=iotus0+1,notus1
          rbdwk(ibnd)=dist(iotus0,iotus1)
          nbdwk(0,ibnd)=iotus0
          nbdwk(1,ibnd)=iotus1
          ibnd=ibnd+1
 100    continue
c
c------
cc        write(*,*) (rbdwk(ibnd),ibnd=1,ntbnd)
cc        read(*,*)
c----        
        kflag=2
        call spsort(rbdwk,ntbnd,iperm,kflag,ier)
c------
cc        write(*,*) (rbdwk(ibnd),ibnd=1,ntbnd)
cc        read(*,*)
c----        
c
        ibnd=1
        do 110 iotus0=0,notus1
          do 110 iotus1=iotus0+1,notus1
            do 120 id=0,1
              nbdsrt(id,ibnd)=nbdwk(id,iperm(ibnd))
 120        continue
            ibnd=ibnd+1
 110      continue
c
c----        
cc          write(*,*) (nbdsrt(0,ibnd),ibnd=1,ntbnd)
cc          write(*,*) (nbdsrt(1,ibnd),ibnd=1,ntbnd)
cc        read(*,*)
c----        
        ibnd=0
 130    continue
          ntie=0
 140      continue
            ntie=ntie+1
            ibnd=ibnd+1
            if (ibnd.eq.ntbnd) goto 160
          if (rbdwk(ibnd).eq.rbdwk(ibnd+1)) goto 140
 160      continue
c
          do 150 ibndp=ibnd-ntie+1,ibnd
            iotus0=nbdsrt(0,ibndp)
            iotus1=nbdsrt(1,ibndp)
            nbdrnk(0,iotus0,iotus1)=ibnd-(ntie-1)
            nbdrnk(1,iotus0,iotus1)=ibnd
c
c----        
cc            write(*,*) ibndp,iotus0,iotus1,
cc     &      nbdrnk(0,iotus0,iotus1),
cc     &      nbdrnk(1,iotus0,iotus1)
cc        read(*,*)
c----        
c
 150      continue
        if (ibnd.lt.ntbnd) goto 130
c
        return
c
        end

==> nmds.1.2.3.tgz: MDS_final/prep.f <==
      subroutine prep(dist,rbdwk,nbdwk,nbdsrt,nbdrnk,iperm,rval,
     &  notus1,ntbnd,nd1)
c
      implicit none
c
      integer notus1,ntbnd,nd1
c      
      real dist(0:notus1,0:notus1)
      real rbdwk(ntbnd),rval(0:nd1,0:notus1)
c      
      integer nbdsrt(0:1,ntbnd),nbdwk(0:1,ntbnd)
      integer nbdrnk(0:1,0:notus1,0:notus1)
      integer iperm(ntbnd)
c
      integer ibnd,iotus0,iotus1,kflag,ier,ntie,id,ibndp
c
      call distcal1(notus1,dist)
c
      ibnd=1
      do 100 iotus0=0,notus1
        do 100 iotus1=iotus0+1,notus1
          rbdwk(ibnd)=dist(iotus0,iotus1)
          nbdwk(0,ibnd)=iotus0
          nbdwk(1,ibnd)=iotus1
          ibnd=ibnd+1
 100    continue
c
c------
cc        write(*,*) (rbdwk(ibnd),ibnd=1,ntbnd)
cc        read(*,*)
c----        
        kflag=2
        call spsort(rbdwk,ntbnd,iperm,kflag,ier)
c------
cc        write(*,*) (rbdwk(ibnd),ibnd=1,ntbnd)
cc        read(*,*)
c----        
c
        ibnd=1
        do 110 iotus0=0,notus1
          do 110 iotus1=iotus0+1,notus1
            do 120 id=0,1
              nbdsrt(id,ibnd)=nbdwk(id,iperm(ibnd))
 120        continue
            ibnd=ibnd+1
 110      continue
c
c----        
cc          write(*,*) (nbdsrt(0,ibnd),ibnd=1,10)
cc          write(*,*) (nbdsrt(1,ibnd),ibnd=1,10)
c----        
        ibnd=0
 130    continue
          ntie=0
 140      continue
            ntie=ntie+1
            ibnd=ibnd+1
            if (ibnd.eq.ntbnd) goto 160
          if (rbdwk(ibnd).eq.rbdwk(ibnd+1)) goto 140
 160      continue
c
          do 150 ibndp=ibnd-ntie+1,ibnd
            iotus0=nbdsrt(0,ibndp)
            iotus1=nbdsrt(1,ibndp)
            nbdrnk(0,iotus0,iotus1)=ibnd-(ntie-1)
            nbdrnk(1,iotus0,iotus1)=ibnd
c
c----        
cc            write(*,*) ibndp,iotus0,iotus1,
cc     &      nbdrnk(0,iotus0,iotus1),
cc     &      nbdrnk(1,iotus0,iotus1)
cc        read(*,*)
c----        
c
 150      continue
        if (ibnd.lt.ntbnd) goto 130
c
        return
c
        end
